@@ -28,7 +28,7 @@
 #include <kconfigdialog.h>
 #include <kiconloader.h>
 #include <kwin.h>
-
+#include <dcopref.h>
 
 MainWindow::MainWindow(QWidget * parent, const char * name) :
         DCOPObject("DCOPInterface"),
@@ -41,11 +41,10 @@ MainWindow::MainWindow(QWidget * parent, const char * name) :
     full_screen = false;
     is_shutting_down = false;
     background_changed = false;
+    use_translucency = false;
 
     KConfig config(CONFIG_FILE);
 
-    initWindowProps();
-
     back_widget = new QWidget(this);
     widgets_stack = new QWidgetStack(this);
 
@@ -56,6 +55,12 @@ MainWindow::MainWindow(QWidget * parent, const char * name) :
         kapp->dcopClient()->setDefaultObject(objId());
     }
 
+    // KRootPixmap::isAvailable() is unreliable, so we check
+    // for kdesktop's presence ourselves to decide whether or
+    // not to disable pseudo-translucency.
+    if (Settings::translucency() && kapp->dcopClient()->isApplicationRegistered("kdesktop"))
+        use_translucency = true;
+
     // Revert to default skin if selected skin can't be located.
     if (!locate("appdata", Settings::skin() + "/title.skin"))
         Settings::setSkin("default");
@@ -69,67 +74,69 @@ MainWindow::MainWindow(QWidget * parent, const char * name) :
     global_key->readSettings(&config);
     global_key->updateConnections();
 
+
+
     // Initialize shortcuts.
     KAction* action;
 
     KShortcut shortcut(Qt::CTRL+Qt::ALT+Qt::Key_N);
     shortcut.append(KShortcut(Qt::CTRL+Qt::SHIFT+Qt::Key_N));
     action = new KAction(i18n("New Session"), SmallIcon("tab_new"), shortcut,
-                             this, SLOT(slotAddSession()),
-                             actionCollection(), "add_tab");
+                              this, SLOT(slotAddSession()),
+                              actionCollection(), "add_tab");
 
     action = new KAction(i18n("Two Terminals, Horizontal"), SmallIcon("tab_new"),
-                             0, this, SLOT(slotAddSessionTwoVertical()),
-                             actionCollection(), "add_tab_twohorizontal");
+                              0, this, SLOT(slotAddSessionTwoVertical()),
+                              actionCollection(), "add_tab_twohorizontal");
 
     action = new KAction(i18n("Two Terminals, Vertical"), SmallIcon("tab_new"),
-                             0, this, SLOT(slotAddSessionTwoHorizontal()),
-                             actionCollection(), "add_tab_twovertical");
+                              0, this, SLOT(slotAddSessionTwoHorizontal()),
+                              actionCollection(), "add_tab_twovertical");
 
     action = new KAction(i18n("Four Terminals, Quad"), SmallIcon("tab_new"),
-                             0, this, SLOT(slotAddSessionQuad()),
-                             actionCollection(), "add_tab_quad");
+                              0, this, SLOT(slotAddSessionQuad()),
+                              actionCollection(), "add_tab_quad");
 
     action = new KAction(i18n("Go to Next Terminal"), SmallIcon("next"),
-                             "Ctrl+Shift+Up", this, SLOT(slotFocusNextSplit()),
-                             actionCollection(), "focus_next_terminal");
+                              "Ctrl+Shift+Up", this, SLOT(slotFocusNextSplit()),
+                              actionCollection(), "focus_next_terminal");
 
     action = new KAction(i18n("Go to Previous Terminal"), SmallIcon("previous"),
-                             "Ctrl+Shift+Down", this, SLOT(slotFocusPreviousSplit()),
-                             actionCollection(), "focus_previous_terminal");
+                              "Ctrl+Shift+Down", this, SLOT(slotFocusPreviousSplit()),
+                              actionCollection(), "focus_previous_terminal");
 
     action = new KAction(i18n("Paste"), SmallIcon("editpaste"), SHIFT+Key_Insert,
-                               this, SLOT(slotPasteClipboard()),
-                               actionCollection(), "paste_clipboard");
+                              this, SLOT(slotPasteClipboard()),
+                              actionCollection(), "paste_clipboard");
 
     action = new KAction(i18n("Paste Selection"), SmallIcon("editpaste"),
-                               CTRL+SHIFT+Key_Insert, this, SLOT(slotPasteSelection()),
-                               actionCollection(), "paste_selection");
+                              CTRL+SHIFT+Key_Insert, this, SLOT(slotPasteSelection()),
+                              actionCollection(), "paste_selection");
 
     action = new KAction(i18n("Rename Session..."), SmallIcon("edit"),
-                               "Alt+Ctrl+S", this, SLOT(slotInteractiveRename()),
-                               actionCollection(), "edit_name");
+                              "Alt+Ctrl+S", this, SLOT(slotInteractiveRename()),
+                              actionCollection(), "edit_name");
 
     action = new KAction(i18n("Increase Width"), SmallIcon("viewmag+"),
-                               "Alt+Shift+Right", this, SLOT(slotIncreaseSizeW()),
-                               actionCollection(), "increasew");
+                              "Alt+Shift+Right", this, SLOT(slotIncreaseSizeW()),
+                              actionCollection(), "increasew");
     action = new KAction(i18n("Decrease Width"), SmallIcon("viewmag-"),
-                               "Alt+Shift+Left", this, SLOT(slotDecreaseSizeW()),
-                               actionCollection(), "decreasew");
+                              "Alt+Shift+Left", this, SLOT(slotDecreaseSizeW()),
+                              actionCollection(), "decreasew");
     action = new KAction(i18n("Increase Height"), SmallIcon("viewmag+"),
-                               "Alt+Shift+Down", this, SLOT(slotIncreaseSizeH()),
-                               actionCollection(), "increaseh");
+                              "Alt+Shift+Down", this, SLOT(slotIncreaseSizeH()),
+                              actionCollection(), "increaseh");
     action = new KAction(i18n("Decrease Height"), SmallIcon("viewmag-"),
-                               "Alt+Shift+Up", this, SLOT(slotDecreaseSizeH()),
-                               actionCollection(), "decreaseh");
+                              "Alt+Shift+Up", this, SLOT(slotDecreaseSizeH()),
+                              actionCollection(), "decreaseh");
 
     action = new KAction(i18n("Configure Global Shortcuts..."),
-                               SmallIcon("configure_shortcuts"), 0,
-                               this, SLOT(slotSetAccessKey()),
-                               actionCollection(), "global_shortcuts");
+                              SmallIcon("configure_shortcuts"), 0,
+                              this, SLOT(slotSetAccessKey()),
+                              actionCollection(), "global_shortcuts");
 
     action = new KAction(i18n("Quit"), SmallIcon("exit"), 0, this,
-                               SLOT(close()), actionCollection(), "quit");
+                              SLOT(close()), actionCollection(), "quit");
 
     KStdAction::keyBindings(this, SLOT(slotSetControlKeys()), actionCollection());
     KStdAction::preferences(this, SLOT(slotOpenSettingsDialog()), actionCollection());
@@ -199,12 +206,18 @@ MainWindow::MainWindow(QWidget * parent, const char * name) :
     slotAddSession();
 
     connect(kapp, SIGNAL(aboutToQuit()), this, SLOT(slotAboutToQuit()));
-    connect(kapp, SIGNAL(backgroundChanged(int)), this, SLOT(slotUpdateBackgroundState()));
+
+    // No need for this if we're not going to use pseudo-translucency.
+    if (use_translucency)
+        connect(kapp, SIGNAL(backgroundChanged(int)), this, SLOT(slotUpdateBackgroundState()));
+
     connect(tab_bar, SIGNAL(addItem()), this, SLOT(slotAddSession()));
     connect(tab_bar, SIGNAL(removeItem()), this, SLOT(slotRemoveSession()));
     connect(tab_bar, SIGNAL(itemSelected(int)), this, SLOT(slotSelectSession(int)));
     connect(&desk_info, SIGNAL(workAreaChanged()), this, SLOT(slotUpdateSize()));
 
+    connect(&poller, SIGNAL(timeout()), this, SLOT(slotPollMouse()));
+
     // Startup notification popup.
     if (Settings::popup() && !Settings::firstrun())
         showPopup(i18n("Application successfully started!\nPress %1 to use it...").arg(global_key->shortcut("AccessKey").toString()));
@@ -215,13 +228,13 @@ MainWindow::MainWindow(QWidget * parent, const char * name) :
         QTimer::singleShot(0, this, SLOT(slotToggleState()));
         QTimer::singleShot(0, this, SLOT(slotOpenFirstRunDialog()));
     }
+    else if (Settings::poll())
+        toggleMousePoll(true);
 }
 
 MainWindow::~MainWindow()
 {
-
-    if (!is_shutting_down)
-        slotAboutToQuit();
+    if (!is_shutting_down) slotAboutToQuit();
 
     delete remove_tab_action;
     delete split_horiz_action;
@@ -678,7 +691,14 @@ void MainWindow::initWindowProps()
 {
     /* Initializes the window properties. */
 
-    KWin::setState(winId(), NET::KeepAbove | NET::Sticky | NET::SkipTaskbar | NET::SkipPager);
+    if (Settings::focus() && !Settings::keepabove())
+    {
+        KWin::clearState(winId(), NET::KeepAbove);
+        KWin::setState(winId(), NET::Sticky | NET::SkipTaskbar | NET::SkipPager);
+    }
+    else
+        KWin::setState(winId(), NET::KeepAbove | NET::Sticky | NET::SkipTaskbar | NET::SkipPager);
+
     KWin::setOnAllDesktops(winId(), true);
 }
 
@@ -723,7 +743,7 @@ void MainWindow::createTabsBar()
 {
     /* Creates the tabs frame. */
 
-    tab_bar = new TabBar(this, "Session tab bar", Settings::skin());
+    tab_bar = new TabBar(this, "Session tab bar", use_translucency, Settings::skin());
     connect(this, SIGNAL(updateBackground()), tab_bar, SIGNAL(updateBackground()));
 
     tab_bar->setSessionMenu(session_menu);
@@ -946,6 +966,8 @@ void MainWindow::slotIncreaseHeight()
             emit updateBackground();
             background_changed = false;
         }
+
+        if (Settings::poll()) toggleMousePoll(false);
     }
 
     updateWindowMask();
@@ -967,6 +989,9 @@ void MainWindow::slotDecreaseHeight()
         disconnect(&timer, SIGNAL(timeout()), 0, 0);
 
         hide();
+
+        if (Settings::poll()) toggleMousePoll(true);
+
     }
 
     updateWindowMask();
@@ -1001,7 +1026,7 @@ void MainWindow::slotUpdateSize(int new_width, int new_height, int new_location)
 
     // Xinerama aware work area.
     desk_area = getDesktopGeometry();
-    max_height = (desk_area.height() - 1) * new_height / 100;
+    max_height = desk_area.height() * new_height / 100;
 
     // Update the size of the components.
     setGeometry(desk_area.x() + desk_area.width() * new_location * (100 - new_width) / 10000,
@@ -1156,6 +1181,8 @@ void MainWindow::slotUpdateSettings()
 
     slotUpdateSize();
 
+    initWindowProps();
+
     menu->setItemChecked(Focus, Settings::focus());
     title_bar->setFocusButtonEnabled(Settings::focus());
 
@@ -1176,11 +1203,11 @@ void MainWindow::slotOpenSettingsDialog()
 
     KConfigDialog* settings_dialog = new KConfigDialog(this, "settings", Settings::self());
 
-    GeneralSettings* general_settings = new GeneralSettings(0, "General");
+    GeneralSettings* general_settings = new GeneralSettings(settings_dialog, "General");
     settings_dialog->addPage(general_settings, i18n("General"), "package_settings");
     connect(general_settings, SIGNAL(updateSize(int, int, int)), this, SLOT(slotUpdateSize(int, int, int)));
 
-    SkinSettings* skin_settings = new SkinSettings(0, "Skins");
+    SkinSettings* skin_settings = new SkinSettings(settings_dialog, "Skins", use_translucency);
     settings_dialog->addPage(skin_settings, i18n("Skins"), "style");
     connect(skin_settings, SIGNAL(settingsChanged()), settings_dialog, SIGNAL(settingsChanged()));
     connect(settings_dialog, SIGNAL(closeClicked()), skin_settings, SLOT(slotResetSelection()));
@@ -1289,3 +1316,24 @@ void MainWindow::slotDialogFinished()
 
     KWin::activateWindow(winId());
 }
+
+void MainWindow::slotPollMouse()
+{
+    QPoint pos = QCursor::pos();
+
+    if (pos.y() == 0)
+    {
+        if (Settings::screen() == 0) 
+            slotToggleState(); // no need to check x since yakuake should open where the mouse pointer is
+        else if (pos.x() >= getDesktopGeometry().x() && pos.x() <= (getDesktopGeometry().x() + getDesktopGeometry().width()))
+            slotToggleState();
+    }
+}
+
+void MainWindow::toggleMousePoll(bool poll)
+{
+    if (poll)
+        poller.start(Settings::pollinterval());
+    else
+        poller.stop();
+}
